@@ -29,16 +29,17 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
+#include <handy.h>
 #include <string.h>
 #include <webkit2/webkit2.h>
 
 struct _EphyFindToolbar {
-  HdySearchBar parent_instance;
+  GtkBin parent_instance;
 
   GCancellable *cancellable;
   WebKitWebView *web_view;
   WebKitFindController *controller;
+  GtkWidget *search_bar;
   GdTaggedEntry *entry;
   GdTaggedEntryTag *entry_tag;
   GtkWidget *next;
@@ -48,11 +49,9 @@ struct _EphyFindToolbar {
   guint find_again_source_id;
   guint find_source_id;
   char *find_string;
-  gboolean links_only;
-  gboolean typing_ahead;
 };
 
-G_DEFINE_TYPE (EphyFindToolbar, ephy_find_toolbar, HDY_TYPE_SEARCH_BAR)
+G_DEFINE_TYPE (EphyFindToolbar, ephy_find_toolbar, GTK_TYPE_BIN)
 
 enum {
   PROP_0,
@@ -225,13 +224,6 @@ update_find_string (EphyFindToolbar *toolbar)
   g_source_set_name_by_id (toolbar->find_source_id, "[epiphany] do_search");
 }
 
-static gboolean
-ephy_find_toolbar_activate_link (EphyFindToolbar *toolbar,
-                                 GdkModifierType  mask)
-{
-  return FALSE;
-}
-
 static gboolean
 entry_key_press_event_cb (GtkEntry        *entry,
                           GdkEventKey     *event,
@@ -251,11 +243,6 @@ entry_key_press_event_cb (GtkEntry        *entry,
         handled = FALSE;
         break;
     }
-  } else if ((event->state & mask) == GDK_CONTROL_MASK &&
-             (event->keyval == GDK_KEY_Return ||
-              event->keyval == GDK_KEY_KP_Enter ||
-              event->keyval == GDK_KEY_ISO_Enter)) {
-    handled = ephy_find_toolbar_activate_link (toolbar, event->state);
   } else if ((event->state & mask) == GDK_CONTROL_MASK &&
              (gdk_keyval_to_lower (event->keyval) == GDK_KEY_g)) {
     handled = TRUE;
@@ -275,17 +262,6 @@ entry_key_press_event_cb (GtkEntry        *entry,
   return handled;
 }
 
-static void
-entry_activate_cb (GtkWidget       *entry,
-                   EphyFindToolbar *toolbar)
-{
-  if (toolbar->typing_ahead) {
-    ephy_find_toolbar_activate_link (toolbar, 0);
-  } else {
-    ephy_find_toolbar_find_next (toolbar);
-  }
-}
-
 static void
 ephy_find_toolbar_grab_focus (GtkWidget *widget)
 {
@@ -362,7 +338,7 @@ ephy_find_toolbar_load_changed_cb (WebKitWebView   *web_view,
                                    EphyFindToolbar *toolbar)
 {
   if (load_event == WEBKIT_LOAD_STARTED &&
-      hdy_search_bar_get_search_mode (HDY_SEARCH_BAR (toolbar))) {
+      hdy_search_bar_get_search_mode (HDY_SEARCH_BAR (toolbar->search_bar))) {
     ephy_find_toolbar_close (toolbar);
   }
 }
@@ -372,20 +348,17 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
 {
   GtkWidget *clamp;
   GtkWidget *box;
-  GtkSizeGroup *size_group;
 
-  size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+  toolbar->search_bar = hdy_search_bar_new ();
+  gtk_container_add (GTK_CONTAINER (toolbar), toolbar->search_bar);
 
   clamp = GTK_WIDGET (hdy_clamp_new ());
   hdy_clamp_set_maximum_size (HDY_CLAMP (clamp), 400);
   hdy_clamp_set_tightening_threshold (HDY_CLAMP (clamp), 300);
-  gtk_container_add (GTK_CONTAINER (toolbar), clamp);
+  gtk_container_add (GTK_CONTAINER (toolbar->search_bar), clamp);
 
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_style_context_add_class (gtk_widget_get_style_context (box),
-                               GTK_STYLE_CLASS_RAISED);
-  gtk_style_context_add_class (gtk_widget_get_style_context (box),
-                               GTK_STYLE_CLASS_LINKED);
+  gtk_style_context_add_class (gtk_widget_get_style_context (box), "linked");
   gtk_container_add (GTK_CONTAINER (clamp), box);
 
   toolbar->entry = gd_tagged_entry_new ();
@@ -394,7 +367,6 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
   gd_tagged_entry_tag_set_has_close_button (toolbar->entry_tag, FALSE);
 
   gtk_widget_set_hexpand (GTK_WIDGET (toolbar->entry), TRUE);
-  gtk_entry_set_max_length (GTK_ENTRY (toolbar->entry), 512);
   gtk_entry_set_placeholder_text (GTK_ENTRY (toolbar->entry), _("Type to search…"));
   gtk_container_add (GTK_CONTAINER (box), GTK_WIDGET (toolbar->entry));
 
@@ -403,7 +375,6 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
   gtk_widget_set_tooltip_text (toolbar->prev,
                                _("Find previous occurrence of the search string"));
   gtk_container_add (GTK_CONTAINER (box), toolbar->prev);
-  gtk_widget_show_all (toolbar->prev);
   gtk_widget_set_sensitive (toolbar->prev, FALSE);
 
   /* Next */
@@ -413,11 +384,6 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
   gtk_container_add (GTK_CONTAINER (box), toolbar->next);
   gtk_widget_set_sensitive (toolbar->next, FALSE);
 
-  gtk_size_group_add_widget (size_group, GTK_WIDGET (toolbar->entry));
-  gtk_size_group_add_widget (size_group, toolbar->next);
-  gtk_size_group_add_widget (size_group, toolbar->prev);
-  g_object_unref (size_group);
-
   /* connect signals */
   g_signal_connect (toolbar->entry, "icon-release",
                     G_CALLBACK (search_entry_clear_cb), toolbar);
@@ -425,13 +391,13 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
                     G_CALLBACK (entry_key_press_event_cb), toolbar);
   g_signal_connect_after (toolbar->entry, "changed",
                           G_CALLBACK (search_entry_changed_cb), toolbar);
-  g_signal_connect (toolbar->entry, "activate",
-                    G_CALLBACK (entry_activate_cb), toolbar);
+  g_signal_connect_swapped (toolbar->entry, "activate",
+                            G_CALLBACK (ephy_find_toolbar_find_next), toolbar);
   g_signal_connect_swapped (toolbar->next, "clicked",
                             G_CALLBACK (ephy_find_toolbar_find_next), toolbar);
   g_signal_connect_swapped (toolbar->prev, "clicked",
                             G_CALLBACK (ephy_find_toolbar_find_previous), toolbar);
-  hdy_search_bar_connect_entry (HDY_SEARCH_BAR (toolbar),
+  hdy_search_bar_connect_entry (HDY_SEARCH_BAR (toolbar->search_bar),
                                 GTK_ENTRY (toolbar->entry));
 
   search_entry_changed_cb (GTK_ENTRY (toolbar->entry), toolbar);
@@ -655,28 +621,23 @@ ephy_find_toolbar_selection_async (GObject      *source_object,
 }
 
 void
-ephy_find_toolbar_open (EphyFindToolbar *toolbar,
-                        gboolean         links_only,
-                        gboolean         typing_ahead)
+ephy_find_toolbar_open (EphyFindToolbar *toolbar)
 {
   g_assert (toolbar->web_view != NULL);
 
-  toolbar->typing_ahead = typing_ahead;
-  toolbar->links_only = links_only;
-
   webkit_web_view_run_javascript (toolbar->web_view, "window.getSelection().toString();", toolbar->cancellable, ephy_find_toolbar_selection_async, toolbar);
 
   gtk_editable_select_region (GTK_EDITABLE (toolbar->entry), 0, -1);
 
-  hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (toolbar), TRUE);
-  hdy_search_bar_set_show_close_button (HDY_SEARCH_BAR (toolbar), TRUE);
+  hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (toolbar->search_bar), TRUE);
+  hdy_search_bar_set_show_close_button (HDY_SEARCH_BAR (toolbar->search_bar), TRUE);
   gtk_widget_grab_focus (GTK_WIDGET (toolbar->entry));
 }
 
 void
 ephy_find_toolbar_close (EphyFindToolbar *toolbar)
 {
-  hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (toolbar), FALSE);
+  hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (toolbar->search_bar), FALSE);
 
   if (toolbar->web_view == NULL) return;
 
@@ -686,7 +647,7 @@ ephy_find_toolbar_close (EphyFindToolbar *toolbar)
 void
 ephy_find_toolbar_request_close (EphyFindToolbar *toolbar)
 {
-  if (hdy_search_bar_get_search_mode (HDY_SEARCH_BAR (toolbar))) {
+  if (hdy_search_bar_get_search_mode (HDY_SEARCH_BAR (toolbar->search_bar))) {
     g_signal_emit (toolbar, signals[CLOSE], 0);
   }
 }
